@@ -24,6 +24,7 @@ This currently supports:
  * automatic MANIFEST (everything except swap and backup files, *.pyc, and
    revision control)
  * manpages (*.[0-9])
+ * icons (data/icons/<size>/<category>/*.{svg,png})
  * files which should go into /etc (./etc/*, copied verbatim)
  * determining "requires" from import statements in source code
  * determining "provides" from shipped packages and modules
@@ -33,8 +34,6 @@ If you follow above conventions, then you don't need any po/POTFILES.in,
 author, license, etc.) in ./setup.py.
 '''
 
-__version__ = '2.15'
-
 # (c) 2009 Canonical Ltd.
 # Author: Martin Pitt <martin.pitt@ubuntu.com>
 
@@ -42,6 +41,7 @@ import os, os.path, fnmatch, stat, sys, subprocess
 import compiler # TODO: deprecated
 import distutils.core
 
+from distutilsextra import __version__ as __pkgversion
 from distutilsextra.command import *
 import distutils.dir_util
 import distutils.command.clean
@@ -49,6 +49,8 @@ import distutils.command.sdist
 import distutils.command.install
 import distutils.filelist
 
+__version__ = __pkgversion
+
 # FIXME: global variable, to share with build_i18n_auto
 src = {}
 src_all = {}
@@ -69,7 +71,8 @@ def setup(**attrs):
 
     # mark files in etc/*, handled by install_auto
     # don't install distutilsextra if bundled with a source tarball
-    ignore_dirs = ['etc', 'distutilsextra']
+    # ignore packaging
+    ignore_dirs = ['etc', 'distutilsextra', 'debian']
     
     for f in src.copy():
         for d in ignore_dirs:
@@ -555,7 +558,7 @@ class build_i18n_auto(build_i18n.build_i18n):
                 # find extensionless executable scripts which are Python files, and
                 # generate a temporary *.py alias, so that they get caught by
                 # intltool
-                for f in src_all:
+                for f in reduce(lambda x, y: x.union(y[1]), self.distribution.data_files, src_all):
                     f_py = f + '.py'
                     if os.access(f, os.X_OK) and os.path.splitext(f)[1] == '' and \
                             not os.path.exists(f_py):
@@ -595,9 +598,13 @@ class build_kdeui_auto(build_kdeui.build_kdeui):
         # add *.ui files which belong to KDE4
         kdeui_files = []
         for f in src_fileglob(src, '*.ui'):
-            if open(f).readline().startswith('<ui version="'):
+            fd = open(f)
+            # might be on the first or second line
+            if fd.readline().startswith('<ui version="') or \
+               fd.readline().startswith('<ui version="'):
                 src_mark(src, f)
                 kdeui_files.append(f)
+            fd.close()
         if kdeui_files:
             try:
                 uf = eval(self.ui_files)
@@ -663,7 +670,8 @@ class install_auto(distutils.command.install.install):
                     os.unlink(os.path.join(self.root, f))
                 except OSError:
                     pass
-
+            if not self.root:
+                self.root = ''
             distutils.dir_util.copy_tree('etc', os.path.join(self.root, 'etc'),
                     preserve_times=0, preserve_symlinks=1, verbose=1)
 
