@@ -259,14 +259,6 @@ class Backend(Thread):
                 log.debug(_("Removing enqueued NZB file %s..."), file_name)
                 remove(file_name)
     
-    def newzbinEnqueue(self, newzbin_id):
-        try:
-            self.update_state(self.__server.enqueuenewzbin(newzbin_id))
-        except:
-            log.error(_("Could not add file to the download queue."))
-        else:
-            log.info(_("Added %s to the download queue.") % (newzbin_id))
-    
     def dequeue(self, download):
         try:
             if download:
