@@ -811,7 +811,7 @@ class LottaConfigRoot(ConfigRoot):
     backend = gproperty(type=object)
     plugins = gproperty(type=object)
     
-    revision = gproperty(type=int, default=3)
+    revision = gproperty(type=int, default=4)
     
     def load(self):
         """
@@ -863,7 +863,7 @@ class LottaConfigRoot(ConfigRoot):
             self.save()
             
             if newest_revision > current_revision:
-                log.debug(_("Configuration upgraded to revision %i."),
+                log.info(_("Configuration upgraded to revision %i."),
                     newest_revision)
     
     def try_to_move_option(self, source, dest):
@@ -877,6 +877,23 @@ class LottaConfigRoot(ConfigRoot):
         except OptionError, error:
             log.debug(str(error))
     
+    def try_to_delete_option(self, path):
+        """
+        Invokes the `delete_unknown_property` method and ignores any
+        `OptionError`s that might be raised.
+        
+        `ValueError`s will not be catched because they need to be fixed by the
+        developer.
+        """
+        
+        try:
+            section = self.get_by_path(path[:-1])
+            
+            if path[-1] in section:
+                del section[path[-1]]
+        except OptionError, error:
+            log.debug(str(error))
+    
     def upgrade_1_to_2(self):
         """
         Separating the GUI code from LottaNZB's core and and the creation of
@@ -895,13 +912,18 @@ class LottaConfigRoot(ConfigRoot):
         )
 
     def upgrade_2_to_3(self):
-        """The "notification_area" plug-in has been renamed to "panel_menu"."""
+        """The 'notification_area' plug-in has been renamed to 'panel_menu'."""
         
         self.try_to_move_option(
             ["plugins", "notification_area"],
             ["plugins", "panel_menu"]
         )
     
+    def upgrade_3_to_4(self):
+        """The 'newzbin' plug-in has been removed."""
+        
+        self.try_to_delete_option(["plugins", "newzbin"])
+    
     def convert_xml_config(self):
         """
         Convert an existing XML configuration file to the new format.
