@@ -25,6 +25,7 @@ from gobject import list_properties
 from os import getcwd, makedirs
 from os.path import isfile, exists, join, expanduser
 from string import ascii_lowercase, ascii_uppercase
+from distutils.spawn import find_executable
 
 from lottanzb.util import (
     GObject, gproperty, gsignal, has_ssl_support, get_unrar_cmd, get_par_cmd, _)
@@ -870,9 +871,6 @@ class HellaConfig(GObject):
         
         return output
     
-    def newzbin_support(self):
-        return bool(self.newzbin_username and self.newzbin_password)
-    
     @staticmethod
     def upper_ascii(value):
         """
