@@ -101,7 +101,7 @@ class PluginBase(GObject):
     # A list of all plug-ins that need to be enabled before this plug-in may
     # be enabled. Additionally, this plug-in will automatically be disabled if
     # one of the plug-ins in this list is disabled.
-    # Example: ["newzbin"]
+    # Example: ["panel_menu"]
     requires = []
     
     # A list of lottanzb.modes.Mode subclasses.
@@ -150,7 +150,7 @@ class PluginBase(GObject):
             plug-in cannot be enabled.
             """
             
-            if key == "enabled" and value and not self.enabled:
+            if key == "enabled" and value:
                 try:
                     if self.locked:
                         # The plug-in is locked and can therefore not be enabled
