@@ -15,7 +15,7 @@
 
 __all__ = ["INSTALLED", "DATA_DIR", "HELP_DIR", "LOCALE_DIR"]
 
-INSTALLED = True
+INSTALLED = False
 
 DATA_DIR = "data"
 HELP_DIR = "help"
